@@ -27,11 +27,6 @@
 #include <SDL.h>
 #include <SDL_image.h>
 #include <assert.h>
-#ifdef SAVES_IN_HOME
-#include <unistd.h>
-#include <sys/types.h>
-#include <pwd.h>
-#endif
 
 #include "mapgen.h"
 #include "demon.h"
@@ -43,11 +38,12 @@
 #include "boss.h"
 #include "ending.h"
 #include "levelblit.h"
+#include "i18n.h"
 
 #define PLAYERW 16
 #define PLAYERH 24
 
-#define MERITOUS_VERSION "v 1.3"
+#define MERITOUS_VERSION "v 1.5"
 int RECORDING = 0;
 int PLAYBACK = 0;
 
@@ -67,11 +63,7 @@ int agate_knife_loc = -1;
 
 FILE *record_file;
 char record_filename[256];
-#ifdef SAVES_IN_HOME
-char save_filename[1024];
-#else
-char* save_filename = "SaveFile.sav";
-#endif
+char save_filename[1024] = "SaveFile.sav";
 
 void DrawLevel(int off_x, int off_y, int hide_not_visited, int fog_of_war);
 void DrawPlayer(int x, int y, int pl_dir, int pl_frm);
@@ -433,11 +425,12 @@ int main(int argc, char **argv)
 	int fullscreen = 0;
 	int ticker_tick = 0;
 	unsigned int stime = 0;
+
+	setlocale(LC_ALL, "");
+	bindtextdomain("meritous", LOCALEDIR);
+	textdomain("meritous");
 	
 	FILE *wm_mask_file;
-#ifdef SAVES_IN_HOME
-	struct passwd *pw_record;
-#endif
 
 	if (argc > 1) {
 		for (i = 1; i < argc; i++) {
@@ -467,25 +460,13 @@ int main(int argc, char **argv)
 		}
 	}
 
-#ifdef SAVES_IN_HOME
-	/* Determine the name of the save game file, which is
-	   $HOME/.meritous.sav on POSIX-based machines. */
-	pw_record = getpwuid(getuid());
-	save_filename[0] = 0;
-
-	if (pw_record != NULL) {
-		/* Just a bit of sanity checking on the length */
-		if (strlen(pw_record->pw_dir) > 1000) {
-			/* Just use the working directory */
-			strcpy(save_filename, "SaveFile.sav");
-		} else {
-			/* Set the filename based on the user's directory */
-			strcpy(save_filename, pw_record->pw_dir);
-			strcat(save_filename, "/.meritous.sav");
-		}
-	} else {
-	    	/* We couldn't find it, so just use the working directory */
-	    	strcpy(save_filename, "SaveFile.sav");
+#if defined __ANDROID__ || defined _WIN32 || defined __WIN32__ || defined __CYGWIN__
+	// save in current directory
+#else
+	char* envhome = getenv("HOME");
+	if (envhome) {
+		snprintf(save_filename, sizeof(save_filename), "%s/%s",
+		         envhome, ".meritous.sav");
 	}
 #endif
 
@@ -516,14 +497,23 @@ int main(int argc, char **argv)
 	
 	asceai = IMG_Load(DATADIR "/i/asceai.png");
 	wm_icon = IMG_Load(DATADIR "/i/icon.png");
+	if (wm_icon == NULL) {
+		fprintf(stderr, _("Cannot open %s: %s\n"),
+			DATADIR "/i/icon.png", IMG_GetError());
+		fprintf(stderr, _("Make sure the game data is installed.\n"));
+		exit(1);
+	}
 	
 	screen = SDL_SetVideoMode(SCREEN_W, SCREEN_H, 8, SDL_SWSURFACE | (SDL_FULLSCREEN * fullscreen));
 	
-	wm_mask_file = fopen(DATADIR "/d/icon_bitmask.dat", "rb");
-	fread(wm_mask, 1, 128, wm_mask_file);
-	fclose(wm_mask_file);
 	SDL_WM_SetCaption("~ m e r i t o u s ~", "MT");
-	SDL_WM_SetIcon(wm_icon, wm_mask);
+	wm_mask_file = fopen(DATADIR "/d/icon_bitmask.dat", "rb");
+	if (wm_mask_file) {
+		if (fread(wm_mask, 1, 128, wm_mask_file) == 128) {
+			SDL_WM_SetIcon(wm_icon, wm_mask);
+		}
+		fclose(wm_mask_file);
+	}
 	InitAudio();
 	
 	text_init();
@@ -571,7 +561,7 @@ int main(int argc, char **argv)
 		ticker_tick = 0;
 		TitleScreenMusic();
 		
-		if (IsSaveFile("SaveFile.sav") || IsSaveFile(save_filename)) {
+		if (IsSaveFile(save_filename)) {
 			/* See if we have the old or the new filename */
 			can_continue = 1;
 		} else {
@@ -596,9 +586,9 @@ int main(int argc, char **argv)
 			SDL_BlitSurface(title_pr, NULL, screen, NULL);
 			
 			draw_text(17, 156, MERITOUS_VERSION, 225 + sin((float)ticker_tick / 15)*30);
-			if (can_continue) draw_text((SCREEN_W - 14*8)/2, 310, "Continue", 255);
-			draw_text((SCREEN_W - 14*8)/2, 310 + can_continue*10, "New Game", 255);
-			draw_text((SCREEN_W - 14*8)/2, 320 + can_continue*10, "New Game (Wuss mode)", 255);
+			if (can_continue) draw_text((SCREEN_W - 14*8)/2, 310, _("Continue"), 255);
+			draw_text((SCREEN_W - 14*8)/2, 310 + can_continue*10, _("New Game"), 255);
+			draw_text((SCREEN_W - 14*8)/2, 320 + can_continue*10, _("New Game (Wuss mode)"), 255);
 			
 			if (ticker_tick >= 30) {
 				draw_text((SCREEN_W - 14*8)/2 - 17, 310 + option * 10, "-", 205 + sin((float)ticker_tick / 5.0)*24);
@@ -650,15 +640,7 @@ int main(int argc, char **argv)
 			SDL_FreeSurface(title);
 			SDL_FreeSurface(title_pr);
 			if ((option == 0) && can_continue) {
-#ifdef SAVES_IN_HOME
-			    if (IsSaveFile(save_filename)) {
 				DungeonPlay(save_filename);
-			    } else {
-#endif
-				DungeonPlay("SaveFile.sav");
-#ifdef SAVES_IN_HOME
-			    }
-#endif
 			} else {
 				if (option == (0 + can_continue)) {
 					training = 0;
@@ -736,13 +718,13 @@ void LoadingScreen(int part, float progress)
 	if (game_load) t_parts = 5.0;
 	else t_parts = 3.0;
 	
-	ProgressBarScreen(part, progress, "Loading... please wait", t_parts);
+	ProgressBarScreen(part, progress, _("Loading... please wait"), t_parts);
 	ClearInput();
 }
 
 void SavingScreen(int part, float progress)
 {
-	ProgressBarScreen(part, progress, "Saving... please wait", 4.0);
+	ProgressBarScreen(part, progress, _("Saving... please wait"), 4.0);
 	ClearInput();
 }
 
@@ -841,6 +823,15 @@ int DungeonPlay(char *fname)
 	}
 	
 	game_running = 1;
+
+	/* for (;;) { */
+	/* 	DrawCredits(); */
+	/* 	EndCycle(0); */
+	/* 	if (EndingEvents()) return; */
+	/* } */
+
+	/* ShowEnding(); */
+
 	while (game_running) {
 		//sprintf(buf, "X: %d  Y: %d", (player_x + PLAYERW/2)/32*32 + PLAYERW/2, (player_y + PLAYERH/2)/32*32 + PLAYERH/2);
 		//SDL_WM_SetCaption(buf, "MT");
@@ -1068,29 +1059,29 @@ int DungeonPlay(char *fname)
 		DrawRect(2, 2, 636, 25, 64);
 		
 		if (!tele_select) {
-			sprintf(buf, "Psi Crystals: %d", player_gems);
+			sprintf(buf, _("Psi Crystals: %d"), player_gems);
 			draw_text(3, 3, buf, 200);
-			sprintf(buf, "Explored: %.1f%% (%d/%d rooms)", (float)explored/30.0, explored, 3000);
+			sprintf(buf, _("Explored: %.1f%% (%d/%d rooms)"), (float)explored/30.0, explored, 3000);
 			draw_text(3, 11, buf, 200);
-			sprintf(buf, "Cleared: %.1f%% (%d/%d monsters)", (float)killed_enemies/(float)total_enemies*100.0, killed_enemies, total_enemies);
+			sprintf(buf, _("Cleared: %.1f%% (%d/%d monsters)"), (float)killed_enemies/(float)total_enemies*100.0, killed_enemies, total_enemies);
 			draw_text(3, 19, buf, 200);
 			
-			draw_text(316, 3, "Reflect shield", (player_gems >= UpgradePrice(0))&&(player_shield!=30) ? (231 + (t%13)*2) : 200);
+			draw_text(316, 3, _("Reflect shield"), (player_gems >= UpgradePrice(0))&&(player_shield!=30) ? (231 + (t%13)*2) : 200);
 			DrawMeter(434, 3, player_shield);
 			
-			draw_text(316, 11, "Circuit charge", (player_gems >= UpgradePrice(1))&&(circuit_fillrate!=30) ? (231 + (t%13)*2) : 200);
+			draw_text(316, 11, _("Circuit charge"), (player_gems >= UpgradePrice(1))&&(circuit_fillrate!=30) ? (231 + (t%13)*2) : 200);
 			DrawMeter(434, 11, circuit_fillrate);
 			
-			draw_text(316, 19, "Circuit refill", (player_gems >= UpgradePrice(2))&&(circuit_recoverrate!=30) ? (231 + (t%13)*2) : 200);
+			draw_text(316, 19, _("Circuit refill"), (player_gems >= UpgradePrice(2))&&(circuit_recoverrate!=30) ? (231 + (t%13)*2) : 200);
 			DrawMeter(434, 19, circuit_recoverrate);
 			
 		} else {
 #ifdef __ANDROID__
-			draw_text(80, 11-6, "Use the movement keys to locate a checkpoint. Press button 1 to", 240);
-			draw_text(52, 11+6, "teleport to this checkpoint. Press Back or 3 once you are done.", 240);
+			draw_text(80, 11-6, _("Use the movement keys to locate a checkpoint. Press button 1 to"), 240);
+			draw_text(52, 11+6, _("teleport to this checkpoint. Press Back or 3 once you are done."), 240);
 #else
-			draw_text(80, 11-6, "Use the movement keys to locate a checkpoint. Press ENTER to", 240);
-			draw_text(52, 11+6, "teleport to this checkpoint. Press ESCAPE or TAB once you are done.", 240);
+			draw_text(80, 11-6, _("Use the movement keys to locate a checkpoint. Press ENTER to"), 240);
+			draw_text(52, 11+6, _("teleport to this checkpoint. Press ESCAPE or TAB once you are done."), 240);
 #endif
 		}
 		
@@ -1156,7 +1147,7 @@ int DungeonPlay(char *fname)
 			for (i = 0; i < 10; i++) {
 				DrawRect((640 - 6 * 8) / 2 - i, (480 - 8) / 2 - i, 6*8 + 2*i, 8 + 2*i, 64 - i*5);
 			}
-			draw_text((640 - 6 * 8) / 2, (480 - 8) / 2, "Paused", 255);
+			draw_text((640 - 6 * 8) / 2, (480 - 8) / 2, _("Paused"), 255);
 			
 			{
 				int t_days;
@@ -1185,11 +1176,11 @@ int DungeonPlay(char *fname)
 		if (voluntary_exit) {
 			DrawRect(152, 200, 336, 80, 128);
 			DrawRect(160, 208, 320, 64, 64);
-			draw_text((640 - 30 * 8) / 2, (480 - 8) / 2 - 4, "Are you sure you want to quit?", 255);
+			draw_text((640 - 30 * 8) / 2, (480 - 8) / 2 - 4, _("Are you sure you want to quit?"), 255);
 #ifdef __ANDROID__
-			draw_text((640 - 23 * 8) / 2, (480 - 8) / 2 + 4, "Press button 2 to confirm.", 255);
+			draw_text((640 - 26 * 8) / 2, (480 - 8) / 2 + 4, _("Press button 2 to confirm."), 255);
 #else
-			draw_text((640 - 23 * 8) / 2, (480 - 8) / 2 + 4, "Press enter to confirm.", 255);
+			draw_text((640 - 23 * 8) / 2, (480 - 8) / 2 + 4, _("Press enter to confirm."), 255);
 #endif
 		}
 		
@@ -1323,7 +1314,7 @@ int DungeonPlay(char *fname)
 	
 	if ((player_lives == 0) && (!training)) {
 		SDL_FillRect(screen, NULL, 0);
-		draw_text(252, 236, "G A M E   O V E R", 255);
+		draw_text(252, 236, _("G A M E   O V E R"), 255);
 		VideoUpdate();
 		SDL_Delay(2000);
 	}
@@ -2016,7 +2007,7 @@ void DrawCircuit()
 	}
 	sprintf(buf, "%.1f", fabs((float)magic_circuit / 100.0));
 	draw_text(115, 470, buf, 0);
-	draw_text(3, 469, "Psi Circuit", 200);
+	draw_text(3, 469, _("Psi Circuit"), 200);
 }
 
 void ReleaseCircuit()
@@ -2511,74 +2502,74 @@ void SpecialTile(int x, int y)
 	switch (tile) {
 		case 25:
 			if (artifacts[11]) {
-				sprintf(message, "This is a checkpoint, but it doesn't seem to be working");
+				sprintf(message, _("This is a checkpoint, but it doesn't seem to be working") );
 				break;
 			}
 			if (checkpoints_found <= 1) {
-				sprintf(message, "This is a checkpoint. You will return here when you die.");
+				sprintf(message, _("This is a checkpoint. You will return here when you die."));
 			} else {
 #ifdef __ANDROID__
-				sprintf(message, "Press button 2 to teleport between checkpoints.");
+				sprintf(message, _("Press button 2 to teleport between checkpoints.") );
 #else
-				sprintf(message, "Press ENTER to teleport between checkpoints.");
+				sprintf(message, _("Press ENTER to teleport between checkpoints.") );
 #endif
 			}
 			break;
 		case 26:
 #ifdef __ANDROID__
-			sprintf(message, "Press button 2 to open the storage chest");
+			sprintf(message, _("Press button 2 to open the storage chest") );
 #else
-			sprintf(message, "Press ENTER to open the storage chest");
+			sprintf(message, _("Press ENTER to open the storage chest") );
 #endif
 			break;
 		case 28:
 			if (player_shield >= 25) {
-				sprintf(message, "Your shield is already at full efficiency");
+				sprintf(message, _("Your shield is already at full efficiency") );
 			} else {
 #ifdef __ANDROID__
-				sprintf(message, "Press button 2 to upgrade shields (%d crystals)", UpgradePrice(0));
+				sprintf(message, _("Press button 2 to upgrade shields (%d crystals)"), UpgradePrice(0));
 #else
-				sprintf(message, "Press ENTER to upgrade shields (%d crystals)", UpgradePrice(0));
+				sprintf(message, _("Press ENTER to upgrade shields (%d crystals)"), UpgradePrice(0));
 #endif
 			}
 			break;
 		case 29:
 			if (circuit_fillrate >= 25) {
-				sprintf(message, "Your circuit charge rate is already at its highest");
+				sprintf(message, _("Your circuit charge rate is already at its highest") );
 			} else {
 #ifdef __ANDROID__
-				sprintf(message, "Press button 2 to upgrade circuit charge (%d crystals)", UpgradePrice(1));
+				sprintf(message, _("Press button 2 to upgrade circuit charge (%d crystals)"), UpgradePrice(1));
 #else
-				sprintf(message, "Press ENTER to upgrade circuit charge (%d crystals)", UpgradePrice(1));
+				sprintf(message, _("Press ENTER to upgrade circuit charge (%d crystals)"), UpgradePrice(1));
 #endif
 			}
 			break;
 		case 30:
 			if (circuit_recoverrate >= 25) {
-				sprintf(message, "Your circuit refill rate is already at its highest");
+				sprintf(message, _("Your circuit refill rate is already at its highest") );
 			} else {
 #ifdef __ANDROID__
-				sprintf(message, "Press button 2 to upgrade circuit refill (%d crystals)", UpgradePrice(2));
+				sprintf(message, _("Press button 2 to upgrade circuit refill (%d crystals)"), UpgradePrice(2));
 #else
-				sprintf(message, "Press ENTER to upgrade circuit refill (%d crystals)", UpgradePrice(2));
+				sprintf(message, _("Press ENTER to upgrade circuit refill (%d crystals)"), UpgradePrice(2));
 #endif
 			}
 			break;
 		case 31:
 #ifdef __ANDROID__
-			sprintf(message, "Press button 2 to record your progress");
+			sprintf(message, _("Press button 2 to record your progress") );
 #else
-			sprintf(message, "Press ENTER to record your progress");
+			sprintf(message, _("Press ENTER to record your progress") );
 #endif
 			break;
 		case 32:
 			if (total_gems == 0) {
-				sprintf(message, "This is a crystal device. It isn't working at the moment.");
+				sprintf(message, _("This is a crystal device. It isn't working at the moment.") );
 			} else {
 #ifdef __ANDROID__
-				sprintf(message, "Press button 2 to activate the crystal device");
+				sprintf(message, _("Press button 2 to activate the crystal device") );
 #else
-				sprintf(message, "Press ENTER to activate the crystal device");
+				sprintf(message, _("Press ENTER to activate the crystal device") );
 #endif
 			}
 			break;
@@ -2587,7 +2578,7 @@ void SpecialTile(int x, int y)
 				if (CanGetArtifact(rooms[player_room].room_param)) {
 					
 				} else {
-					sprintf(message, "The artifact is tainted with shadow. You must slay more of the shadow first.");
+					sprintf(message, _("The artifact is tainted with shadow. You must slay more of the shadow first.") );
 				}
 			}
 			break;
@@ -2598,9 +2589,9 @@ void SpecialTile(int x, int y)
 			if (first_game) {
 				if (otext < 60) {
 #ifdef __ANDROID__
-					sprintf(message, "Press Menu to read the help file");
+					sprintf(message, _("Press 4 to read the help file") );
 #else
-					sprintf(message, "Press H to read the help file");
+					sprintf(message, _("Press H to read the help file"));
 #endif
 					otext++;
 				}
@@ -2611,33 +2602,33 @@ void SpecialTile(int x, int y)
 	if (message[0] == 0) {
 		if (specialmessage != 0) {
 			switch (specialmessage) {
-				case 1: sprintf(message, "Ancient artifact: Complete Map"); break;
-				case 2: sprintf(message, "Ancient artifact: Shield boost"); break;
-				case 3: sprintf(message, "Ancient artifact: Extra crystal efficiency"); break;
-				case 4: sprintf(message, "Ancient artifact: Circuit booster"); break;
-				case 5: sprintf(message, "Ancient artifact: Metabolism increase"); break;
-				case 6: sprintf(message, "Ancient artifact: Dodge enhancer"); break;
-				case 7: sprintf(message, "Ancient artifact: Ethereal Monocle"); break;
-				case 8: sprintf(message, "Ancient artifact: Crystal gatherer"); break;
+				case 1: sprintf(message, _("Ancient artifact: Complete Map") ); break;
+				case 2: sprintf(message, _("Ancient artifact: Shield boost") ); break;
+				case 3: sprintf(message, _("Ancient artifact: Extra crystal efficiency") ); break;
+				case 4: sprintf(message, _("Ancient artifact: Circuit booster") ); break;
+				case 5: sprintf(message, _("Ancient artifact: Metabolism increase") ); break;
+				case 6: sprintf(message, _("Ancient artifact: Dodge enhancer") ); break;
+				case 7: sprintf(message, _("Ancient artifact: Ethereal Monocle") ); break;
+				case 8: sprintf(message, _("Ancient artifact: Crystal gatherer") ); break;
 				
-				case 10: sprintf(message, "Enhancement: Shield upgrade"); break;
-				case 11: sprintf(message, "Enhancement: Circuit charge upgrade"); break;
-				case 12: sprintf(message, "Enhancement: Circuit refill upgrade"); break;
+				case 10: sprintf(message, _("Enhancement: Shield upgrade") ); break;
+				case 11: sprintf(message, _("Enhancement: Circuit charge upgrade") ); break;
+				case 12: sprintf(message, _("Enhancement: Circuit refill upgrade") ); break;
 				
-				case 20: sprintf(message, "Reward: Psi crystals"); break;
+				case 20: sprintf(message, _("Reward: Psi crystals") ); break;
 				
-				case 30: sprintf(message, "Holy Sword 'Balmung' answers your call"); break;
-				case 31: sprintf(message, "Mystic Halberd 'Amenonuhoko' answers your call"); break;
-				case 32: sprintf(message, "Divine Bow 'Gandiva' answers your call"); break;
-				case 33: sprintf(message, "You capture the cursed seal. Return to the entrance"); break;
+				case 30: sprintf(message, _("Holy Sword 'Balmung' answers your call") ); break;
+				case 31: sprintf(message, _("Mystic Halberd 'Amenonuhoko' answers your call") ); break;
+				case 32: sprintf(message, _("Divine Bow 'Gandiva' answers your call") ); break;
+				case 33: sprintf(message, _("You capture the cursed seal. Return to the entrance") ); break;
 				
-				case 40: sprintf(message, "Balmung will remain here, where the ley lines are strong"); break;
-				case 41: sprintf(message, "Amenonuhoko will remain here, where the ley lines are strong"); break;
-				case 42: sprintf(message, "Gandiva will remain here, where the ley lines are strong"); break;
+				case 40: sprintf(message, _("Balmung will remain here, where the ley lines are strong") ); break;
+				case 41: sprintf(message, _("Amenonuhoko will remain here, where the ley lines are strong") ); break;
+				case 42: sprintf(message, _("Gandiva will remain here, where the ley lines are strong") ); break;
 				
-				case 50: sprintf(message, ". . . . . .   retrieved 'Agate Knife'"); break;
+				case 50: sprintf(message, _(". . . . . .   retrieved 'Agate Knife'") ); break;
 				
-				default: sprintf(message, "ERROR: NO MESSAGE VALUE GIVEN"); break;
+				default: sprintf(message, _("ERROR: NO MESSAGE VALUE GIVEN") ); break;
 			}
 			specialmessagetimer--;
 			if (specialmessagetimer <= 0) {
